@@ -1,11 +1,10 @@
 package Helios::Error::ObjectDriverError;
 
-use 5.008;
 use strict;
 use warnings;
 use base 'Helios::Error::BaseError';
 
-our $VERSION = '2.811_4150';
+our $VERSION = '2.80';
 
 1;
 __END__
