@@ -6,8 +6,9 @@ use warnings;
 
 use Helios::Job;
 use Helios::Error::LoggingError;
+use Helios::ObjectDriver::DBI;
 
-our $VERSION = '2.41';
+our $VERSION = '2.60';
 
 =head1 NAME
 
@@ -121,7 +122,7 @@ sub initDriver {
 	my $self = shift;
 	my $config = $self->getConfig();
 	if ($self->debug) { print $config->{dsn},$config->{user},$config->{password},"\n"; }
-	my $driver = Data::ObjectDriver::Driver::DBI->new(
+	my $driver = Helios::ObjectDriver::DBI->new(
 	    dsn      => $config->{dsn},
 	    username => $config->{user},
 	    password => $config->{password}
